<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/admin
 * @author     Immerseus <dnyaneshmahajan12@gmail.com>
 */
class Learndash_Access_For_Parents_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles( $hook_suffix ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Access_For_Parents_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Access_For_Parents_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ( in_array( $hook_suffix, [ 'parent-access_page_ldpa-settings', 'toplevel_page_ldpa_access', 'parent-access_page_ldpa-mail-settings' ], true ) ) {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/main.css', [], $this->version, 'all' );
			wp_register_style( 'spald-admin-select2-styles', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css', [], '4.1.0-beta.1', 'all' );
			wp_enqueue_style( 'spald-admin-select2-styles' );
		}

	}

	public function init_settings() {
		$general = 'ldpa-settings';

		register_setting( $general, 'ldpa_allow_parents_to_create_accounts_without_email' );
		register_setting( $general, 'ldpa_allow_woocommerce_to_register_as_parent' );

		add_settings_section( $general, __( 'General', 'learndash-access-for-parents' ), null, $general );

		add_settings_field(
			'ldpa_allow_parents_to_create_accounts_without_email',
			__( 'Allow Parents to create accounts without email', 'learndash-access-for-parents' ),
			[ $this, 'field_ldpa_allow_parents_to_create_accounts_without_email' ],
			$general,
			$general
		);

		add_settings_field(
			'ldpa_allow_woocommerce_to_register_as_parent',
			__( 'Allow WooCommerce to Register as Parent', 'learndash-access-for-parents' ),
			[ $this, 'field_ldpa_allow_woocommerce_to_register_as_parent' ],
			$general,
			$general
		);
	}

	public function field_ldpa_allow_parents_to_create_accounts_without_email() {
		$option = get_option( 'ldpa_allow_parents_to_create_accounts_without_email', 0 );

		echo '
            <select name="ldpa_allow_parents_to_create_accounts_without_email" style="width: 100px;">
                <option value="1" ' . selected( $option, 1, false ) . '>
                    ' . __( 'Yes', 'learndash-access-for-parents' ) . '
                </option>
                <option value="0" ' . selected( $option, 0, false ) . '>
                    ' . __( 'No', 'learndash-access-for-parents' ) . '
                </option> 
            </select>
        ';
	}

	public function field_ldpa_allow_woocommerce_to_register_as_parent() {
		$option = get_option( 'ldpa_allow_woocommerce_to_register_as_parent', 0 );

		echo '
			<select name="ldpa_allow_woocommerce_to_register_as_parent" style="width: 100px;">
				<option value="1" ' . selected( $option, 1, false ) . '>
					' . __( 'Yes', 'learndash-access-for-parents' ) . '
				</option>
				<option value="0" ' . selected( $option, 0, false ) . '>
					' . __( 'No', 'learndash-access-for-parents' ) . '
				</option> 
			</select>
		';
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts( $hook_suffix ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Access_For_Parents_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Access_For_Parents_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( in_array( $hook_suffix, [ 'parent-access_page_ldpa-settings', 'toplevel_page_ldpa_access', 'parent-access_page_ldpa-mail-settings' ], true ) ) {
			wp_register_script( 'spald-admin-select2-javascript', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js', [], '4.1.0-beta.1', false );
			wp_enqueue_script( 'spald-admin-select2-javascript' );

			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/learndash-access-for-parents-admin.js', [ 'jquery' ], $this->version, false );
		}
	}

	public function ldpa_register_custom_menus() {

		add_menu_page(
			__( 'Learndash for Parents', 'learndash-access-for-parents' ),
			__( 'Parent Access', 'learndash-access-for-parents' ),
			'manage_options',
			'ldpa_access',
			[ $this, 'ldpa_parent_access_page' ],
			'dashicons-admin-network'
		);

		add_submenu_page(
			'ldpa_access',
			__( 'Settings', 'learndash-access-for-parents' ),
			__( 'Settings', 'learndash-access-for-parents' ),
			'manage_options',
			'ldpa-settings',
			[ $this, 'ldpa_setting_callback' ]
		);

		add_submenu_page(
			'ldpa_access',
			__( 'Confirmation Mail Settings', 'learndash-access-for-parents' ),
			__( 'Confirmation Mail Settings', 'learndash-access-for-parents' ),
			'manage_options',
			'ldpa-mail-settings',
			[ $this, 'ldpa_mail_settings_callback' ]
		);

	}

	public function ldpa_mail_settings_callback() {
		$mail_settings_view = new Learndash_Access_For_Parents_Mail_Settings();
		echo $mail_settings_view->render();
	}

	public function ldpa_parent_access_page() {
		ob_start();
		require_once LEARNDASH_ACCESS_FOR_PARENTS_DIR . 'admin/partials/ldpa-access-page.php';
		$fileContent = ob_get_contents();
		ob_end_clean();
		echo $fileContent;
	}

	function ldpa_setting_callback(){ ?>
		<div id="sfwd-header">
			<div class="header">
				<h1><?php echo __( 'LearnDash Parent Access', 'learndash-access-for-parents' ); ?></h1>
			</div>
			<div class="topnav"></div>
		</div>
		<div class="wrap">
			<h1 class="spald-hidden"><?php echo __( 'LearnDash Parent Access', 'learndash-access-for-parents' ); ?></h1>

			<?php settings_errors(); ?>

			<div class="postbox" style="margin-top: 15px; padding: 0 25px;">
				<form method="post" action="options.php">
					<?php settings_fields( 'ldpa-settings' ); ?>

					<?php do_settings_sections( 'ldpa-settings' ); ?>

					<?php submit_button(); ?>
				</form>
			</div>
		</div>

		<?php
	}

	public function ldpa_delete_parent_to_student() {

		if ( ! wp_verify_nonce( $_REQUEST['nonce'] ) ) {
			exit( 'error' );
		}

		if ( ! isset( $_POST['parent_id'] ) ) {
			exit( 'error' );
		}

		$parentId = $_POST['parent_id'];

		$user = new WP_User( $parentId );
		$user->remove_role( 'parent' );
		$user->remove_cap( 'parent' );

		global $wpdb;
		$table  = $wpdb->prefix . 'ldap_child_parent';
		$data   = [
			'parent_id' => $parentId,
		];
		$format = [ '%d' ];
		$wpdb->delete( $table, $data, $format );

		wp_send_json(
			[
				'status'  => 'success',
				'message' => __( 'Successfully deleted linked student(s) to parent.', 'learndash-access-for-parents' ),
			]
		);

		wp_die();

	}

	public function ldpa_link_parent_student() {

		try {

			if ( ! wp_verify_nonce( $_POST['nonce'] ) ) {
				throw new \Exception( 'Invalid nonce' );
			}

			if ( ! isset( $_POST['parent_id'] ) || ! isset( $_POST['student_ids'] ) ) {
				throw new \Exception( 'The data is invalid.' );
			}

			$parentId   = $_POST['parent_id'];
			$studentIds = $_POST['student_ids'];

			$parent = get_userdata( $parentId );
			$parent->add_role( 'parent' );

			global $wpdb;

			$table = $wpdb->prefix . 'ldap_child_parent';

			$students = $wpdb->get_results( "SELECT child_id FROM $table WHERE parent_id = $parentId", ARRAY_N );

			$sList = [];
			foreach ( $students as $student ) {
				array_push( $sList, $student[0] );
			}

			$results = array_diff( $sList, $studentIds );

			foreach ( $results as $result ) {
				if ( $result != $parentId ) {
					$data   = [
						'parent_id' => $parentId,
						'child_id'  => $result,
					];
					$format = [ '%d', '%d' ];
					$wpdb->delete( $table, $data, $format );
				}
			}

			foreach ( $studentIds as $studentId ) {
				$student = get_userdata( $studentId );
				$student->add_role( 'student' );

				$doesRecordExists = $wpdb->get_row( "SELECT * FROM $table WHERE parent_id = $parentId AND child_id = $studentId" );

				if ( is_null( $doesRecordExists ) ) {
					$data   = [
						'parent_id' => $parentId,
						'child_id'  => $studentId,
					];
					$format = [ '%d', '%d' ];
					$wpdb->insert( $table, $data, $format );
					$mailer = new Learndash_Access_For_Parents_Child_Confirmation_Mailer( $student, $parent );
					$mailer->send();
				}
			}

			wp_send_json(
				[
					'status'  => 'success',
					'message' => __( 'Successfully linked student(s) to parent.', 'learndash-access-for-parents' ),
				]
			);
		} catch ( \Exception $ex ) {
			wp_send_json(
				[
					'status'  => 'error',
					'message' => __( "Couldn\'t save the link because", 'learndash-access-for-parents' ) . " {$ex->getMessage()}",
				]
			);
		}

		wp_die();

	}


	function ldpa_license_key() {

		if ( isset( $_POST['license_key'] ) && $_POST['license_key'] != '' ) {

			$license_key = $_POST['license_key'];

			// $license_keyvar_dump($license_key);
				$ch = curl_init();

				curl_setopt( $ch, CURLOPT_URL, 'https://api.gumroad.com/v2/licenses/verify' );
				curl_setopt( $ch, CURLOPT_POST, 1 );
				curl_setopt(
					$ch,
					CURLOPT_POSTFIELDS,
					'product_permalink=WJNjp&increment_uses_count=false&license_key=' . $license_key
				);

				// In real life you should use something like:
				// curl_setopt($ch, CURLOPT_POSTFIELDS,
				// http_build_query(array('postvar1' => 'value1')));

				// Receive server response ...
				curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );

				$server_output = curl_exec( $ch );

				curl_close( $ch );
				$output = json_decode( $server_output );

			if ( $output->success == 1 &&
					$output->purchase->refunded == '' &&
					$output->purchase->subscription_cancelled_at == '' &&
					$output->purchase->subscription_failed_at == ''
				) {

				update_option( 'ldpa_key_verify', '1' );
				$return = [
					'message' => __( 'Verified', 'learndash-access-for-parents' ),
					'ID'      => 1,
				];

				wp_send_json_success( $return );

			} else {

				wp_send_json_error();

			}
		}
	}
	function ldpa_disable_license_key() {
		update_option( 'ldpa_key_verify', '' );
		$return = [
			'message' => __( 'Deactivated', 'learndash-access-for-parents' ),
			'ID'      => 1,
		];

		wp_send_json_success( $return );
	}



}
