<?php
/**
 * Class for Mail Settings Submenu page
 *
 * @package Learndash_Access_For_Parents
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! class_exists( 'Learndash_Access_For_Parents_Mail_Settings' ) ) {

	/**
	 * Mail Settings for Student Parents plugin
	 *
	 * @version 2.1.0
	 */
	class Learndash_Access_For_Parents_Mail_Settings {

		const DEFAULT_SUBJECT  = "[LearnDash Student Parent] You have been linked to {parent_name}'s account.";
		const DEFAULT_MESSAGE  = 'Hi {child_name}, {parent_name} has invited you to be linked to their account. Please accept the request here {link}';
		const DEFAULT_REDIRECT = '/';

		/**
		 * Construct
		 *
		 * Only Create the options
		 */
		public function __construct() {
			$this->create_options();
		}

		/**
		 * Form Action when is submitted
		 *
		 * @return void
		 * @throws \Exception When is no nonce value.
		 */
		public static function submit_form() {
			try {

				if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'ldpa-mail-settings-nonce' ) ) {
					throw new \Exception( 'Invalid Form data.' );
				}

				if ( isset( $_POST['subject'] ) ) {
					self::update_option_value( 'subject', sanitize_text_field( wp_unslash( $_POST['subject'] ) ) );
				}

				if ( isset( $_POST['message'] ) ) {
					self::update_option_value( 'message', sanitize_text_field( wp_unslash( $_POST['message'] ) ) );
				}

				if ( isset( $_POST['redirect'] ) ) {
					self::update_option_value( 'redirect', sanitize_text_field( wp_unslash( $_POST['redirect'] ) ) );
				}

				wp_send_json(
					[
						'status'  => 'success',
						'message' => __( 'Data has been updated.', 'learndash-access-for-parents' ),
					]
				);
			} catch ( \Exception $ex ) {
				wp_send_json(
					[
						'status'  => 'error',
						'message' => $ex->getMessage(),
					]
				);
			}

			wp_die();
		}

		/**
		 * Update the mail setting option on the DB
		 *
		 * @param string $option subject|message|redirect.
		 * @param string $updates .
		 * @return boolean
		 */
		protected static function update_option_value( $option, $updates ) {
			if ( 'subject' === $option ) {
				return update_option( 'ldpa_overwritten_mail_subject', $updates );
			}

			if ( 'message' === $option ) {
				return update_option( 'ldpa_overwritten_mail_message', $updates );
			}

			if ( 'redirect' === $option ) {
				return update_option( 'ldpa_overwritten_mail_redirect', $updates );
			}

			return false;
		}

		/**
		 * Creation of Options if they don't exist
		 *
		 * @return void
		 */
		public function create_options() {
			if ( ! get_option( 'ldpa_overwritten_mail_subject' ) ) {
				add_option( 'ldpa_overwritten_mail_subject', self::DEFAULT_SUBJECT );
			}

			if ( ! get_option( 'ldpa_overwritten_mail_message' ) ) {
				add_option( 'ldpa_overwritten_mail_message', self::DEFAULT_MESSAGE );
			}

			if ( ! get_option( 'ldpa_overwritten_mail_redirect' ) ) {
				add_option( 'ldpa_overwritten_mail_redirect', self::DEFAULT_REDIRECT );
			}
		}

		/**
		 * Get value of the existing Option
		 *
		 * @param string $option subject|message|redirect.
		 * @return string
		 */
		public static function get_option_value( $option ) {
			if ( 'subject' === $option ) {
				return get_option( 'ldpa_overwritten_mail_subject', '' );
			}

			if ( 'message' === $option ) {
				return get_option( 'ldpa_overwritten_mail_message', '' );
			}

			if ( 'redirect' === $option ) {
				return get_option( 'ldpa_overwritten_mail_redirect', '' );
			}

			return '';
		}

		/**
		 * Render HTML of the Mail setting view.
		 *
		 * @return unknown
		 */
		public function render() {
			ob_start();
			?>
			<div id="sfwd-header" class="spald-hidden">
				<div class="header">
					<h1><?php _e( 'LearnDash Parent Access - Mail Settings', 'learndash-access-for-parents' ); ?></h1>
				</div>
				<div class="topnav"></div>
			</div>
			<div class="wrap">
				<h1 class="spald-hidden"><?php _e( 'LearnDash Parent Access - Mail Settings', 'learndash-access-for-parents' ); ?></h1>

				<div class="spald-bg-white spald-overflow-hidden spald-shadow">
					<div class="spald-container spald-p-4 spald-box-border">
						<h1><?php _e( 'Mail Settings', 'learndash-access-for-parents' ); ?></h1>

						<div id="notification" class="spald-hidden">
							<div class="spald-h-full spald-w-full spald-p-2 spald-my-2 spald-rounded spald-shadow spald-text-white">
							</div>
						</div>

						<form id="mail-settings-form">
							<?php wp_nonce_field( 'ldpa-mail-settings-nonce' ); ?>
							<div class="spald-grid spald-grid-cols-1 spald-gap-y-5 spald-my-6">
								<label class="spald-flex spald-flex-wrap">
									<span class="spald-text-black spald-font-medium spald-text-base"><?php _e( 'Subject:', 'learndash-access-for-parents' ); ?></span>
									<input name="subject" value="<?php echo esc_attr( $this->get_option_value( 'subject' ) ); ?>" class="spald-min-w-full spald-w-20 spald-border-gray-400 spald-bg-white spald-border-solid spald-border spald-rounded spald-mt-2 spald-p-1" placeholder="<?php echo esc_attr( self::DEFAULT_SUBJECT ); ?>" />
									<span class="spald-font-light spald-text-xs spald-text-black spald-italic spald-ml-1"><?php _e( 'Available shortcuts', 'learndash-access-for-parents' ); ?> {parent_name}, {child_name}.</span>
								</label>

								<label class="spald-flex spald-flex-wrap">
									<span class="spald-text-black spald-font-medium spald-text-base"><?php _e( 'Message:', 'learndash-access-for-parents' ); ?></span>
									<textarea name="message" class="spald-min-w-full spald-w-20 spald-border-gray-400 spald-bg-white spald-border-solid spald-border spald-rounded spald-mt-2 spald-p-1" placeholder="<?php echo esc_attr( self::DEFAULT_MESSAGE ); ?>" ><?php echo esc_textarea( $this->get_option_value( 'message' ) ); ?></textarea>
									<span class="spald-font-light spald-text-xs spald-text-black spald-italic spald-ml-1"><?php _e( 'Available shortcuts', 'learndash-access-for-parents' ); ?> {parent_name}, {child_name}, {link}</span>
								</label>

								<label class="spald-flex spald-flex-wrap">
									<span class="spald-text-black spald-font-medium spald-text-base"><?php _e( 'Redirect:', 'learndash-access-for-parents' ); ?></span>
									<input name="redirect" value="<?php echo esc_attr( $this->get_option_value( 'redirect' ) ); ?>" class="spald-min-w-full spald-w-20 spald-border-gray-400 spald-bg-white spald-border-solid spald-border spald-rounded spald-mt-2 spald-p-1" placeholder="<?php echo esc_attr( self::DEFAULT_REDIRECT ); ?>" />
									<span class="spald-font-light spald-text-xs spald-text-black spald-italic spald-ml-1"><?php _e( 'When user confirmed, redirects to a specific page', 'learndash-access-for-parents' ); ?></span>
								</label>
								<div>
									<button type="submit" class="spald-cursor-pointer spald-border-none spald-bg-blue-500 hover:spald-bg-blue-700 spald-text-white spald-font-bold spald-py-2 spald-px-4 spald-rounded sm:spald-mt-2">
										<?php _e( 'Update', 'learndash-access-for-parents' ); ?>
									</button>
								</div>
							</div>
						</form>

					</div>
				</div>
			</div>

			<script>
			(function($) {

				const notification = document.getElementById('notification');

				function resetNotification() {
					// This will reset any previous notification
					notification.classList.add('spald-hidden');
					notification.children[0].classList.remove('spald-bg-green-600');
					notification.children[0].classList.remove('spald-bg-red-600');
				}

				function showNotification(status, message) {
					const color = 'success' === status ? 'green' : 'red'
					notification.classList.remove('spald-hidden');
					notification.children[0].classList.add(`spald-bg-${color}-600`);
					notification.children[0].innerText = message;
				}

				const dataForm = document.getElementById('mail-settings-form');
				dataForm.addEventListener('submit', function(event) {
					event.preventDefault();

					try {
						resetNotification();
						const form = event.target;

						const linkUrl = '<?php echo esc_url( admin_url( 'admin-ajax.php?action=ldpa_mail_settings_form' ) ); ?>';
						const subject = form.elements['subject'].value;
						const message = form.elements['message'].value;
						const redirect = form.elements['redirect'].value;
						const nonce = form.elements['_wpnonce'].value;

						$.ajax({
							method: 'POST',
							url: linkUrl,
							data: {
								nonce,
								subject,
								message,
								redirect
							},
							success: function(response) {
								showNotification(response.status, response.message)
							},
							error: function(response) {
								showNotification('error', response.message)
							}
						}).catch(err => {
							showNotification('error', err.message)
						});
					} catch (err) {
						showNotification('error', err.message)
					}
				});
			})(jQuery)
			</script>


			<?php
			return ob_get_clean();
		}
	}
}

