<?php
/**
 * Email Sender Class
 *
 * @package Learndash_Access_For_Parents
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( 'You can not access this file!' );
}

/**
 * Email Sender class
 */
class Learndash_Access_For_Parents_Email_Sender {

	/**
	 * Child User. Who is receiving the email
	 *
	 * @var WP_User
	 */
	private $child;

	/**
	 * Parent User. Who is sending the email
	 *
	 * @var WP_User
	 */
	private $parent;

	/**
	 * Message of the email
	 *
	 * @var string
	 */
	private $message = '';

	/**
	 * Subject of the email
	 *
	 * @var string
	 */
	private $subject = '';

	/**
	 * Redirect Link will be added to the email
	 *
	 * @var string
	 */
	private $link = '';

	/**
	 * Construct
	 *
	 * @param WP_User $child Who is going to receive the email.
	 * @param WP_User $parent Who is going to send the email.
	 */
	public function __construct( $child, $parent ) {
		$this->child  = $child;
		$this->parent = $parent;
	}

	/**
	 * Triggers the Send email functionality
	 *
	 * @return void
	 * @throws \Exception If something happens will show an error message.
	 */
	public function send() {
		try {
			wp_mail( $this->child->data->user_email, $this->render_subject(), $this->render_message() );
		} catch ( \Exception $error ) {
			throw new \Exception( "Error sending email. {$error->getMessage()}" );
		}
	}

	/**
	 * Returns the message of the email
	 *
	 * @return string
	 */
	public function get_message() {
		return $this->message;
	}

	/**
	 * Set Message for the email
	 *
	 * @param string $message This can be use to set a different email message.
	 * @return void
	 */
	public function set_message( $message ) {
		$this->message = $message;
	}


	/**
	 * Returns the subject of the email
	 *
	 * @return string
	 */
	public function get_subject() {
		return $this->subject;
	}

	/**
	 * Set subject for the email
	 *
	 * @param string $subject This can be use to set a different email subject.
	 * @return void
	 */
	public function set_subject( $subject ) {
		$this->subject = $subject;
	}

	/**
	 * Returns the link, if no custom message will return the default message
	 *
	 * @return string
	 */
	public function get_link() {
		return $this->link;
	}

	/**
	 * Set link for the email
	 *
	 * @param string $link This can be use to set a different email link.
	 * @return void
	 */
	public function set_link( $link ) {
		$this->link = $link;
	}


	/**
	 * Returns the child, if no custom message will return the default message
	 *
	 * @return string
	 */
	public function get_child() {
		return $this->child;
	}

	/**
	 * Set child for the email
	 *
	 * @param string $child This can be use to set a different email child.
	 * @return void
	 */
	public function set_child( $child ) {
		$this->child = $child;
	}


	/**
	 * Returns the parent, if no custom message will return the default message
	 *
	 * @return string
	 */
	public function get_parent() {
		return $this->parent;
	}

	/**
	 * Set parent for the email
	 *
	 * @param string $parent This can be use to set a different email parent.
	 * @return void
	 */
	public function set_parent( $parent ) {
		$this->parent = $parent;
	}

	/**
	 * Returns the rendered message with the replacements
	 *
	 * @return string
	 */
	private function render_message() {
		$message = $this->get_message();

		$to_replace = array(
			'{child_name}',
			'{parent_name}',
			'{link}',
		);

		$replacements = array(
			$this->child ? $this->child->data->display_name : '',
			$this->parent ? $this->parent->data->display_name : '',
			$this->get_link(),
		);

		return str_replace( $to_replace, $replacements, $message );
	}

	/**
	 * Returns the rendered subject with the replacements
	 *
	 * @return string
	 */
	private function render_subject() {
		$subject = $this->get_subject();

		$to_replace = array(
			'{child_name}',
			'{parent_name}',
		);

		$replacements = array(
			$this->child ? $this->child->data->display_name : '',
			$this->parent ? $this->parent->data->display_name : '',
		);

		return str_replace( $to_replace, $replacements, $subject );
	}
}
