<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/includes
 * @author     Immerseus <dnyaneshmahajan12@gmail.com>
 */
class Learndash_Access_For_Parents {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Learndash_Access_For_Parents_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'LEARNDASH_ACCESS_FOR_PARENTS_VERSION' ) ) {
			$this->version = LEARNDASH_ACCESS_FOR_PARENTS_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'learndash-access-for-parents';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Learndash_Access_For_Parents_Loader. Orchestrates the hooks of the plugin.
	 * - Learndash_Access_For_Parents_i18n. Defines internationalization functionality.
	 * - Learndash_Access_For_Parents_Admin. Defines all hooks for the admin area.
	 * - Learndash_Access_For_Parents_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-learndash-access-for-parents-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-learndash-access-for-parents-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-learndash-access-for-parents-admin.php';

		/**
		 * The class responsible for registration information
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-learndash-access-for-parents-registration.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-learndash-access-for-parents-public.php';

		$this->loader = new Learndash_Access_For_Parents_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Learndash_Access_For_Parents_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Learndash_Access_For_Parents_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Learndash_Access_For_Parents_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'ldpa_register_custom_menus' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'init_settings' );
		$this->loader->add_action( 'wp_ajax_link_parent_to_student', $plugin_admin, 'ldpa_link_parent_student' );
		$this->loader->add_action( 'wp_ajax_verify_license_key', $plugin_admin, 'ldpa_license_key' );
		$this->loader->add_action( 'wp_ajax_disable_license_key', $plugin_admin, 'ldpa_disable_license_key' );
		$this->loader->add_action( 'wp_ajax_delete_parent_to_student', $plugin_admin, 'ldpa_delete_parent_to_student' );
		$this->loader->add_action( 'wp_ajax_ldpa_mail_settings_form', 'Learndash_Access_For_Parents_Mail_Settings', 'submit_form' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Learndash_Access_For_Parents_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_public, 'ldpa_register_shortcode' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Learndash_Access_For_Parents_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	public function ldpa_get_enrolled_students() {
		$default_args    = [
			'role__not_in' => [ 'Administrator', 'parent' ],
			'count_total'  => true,
		];
		$user_query_args = apply_filters( 'learndash_students_enrolled_count_qrgs', $default_args );

		if ( ! empty( $user_query_args ) ) {
			$user_query = new WP_User_Query( $user_query_args );
			return $user_query->get_results();
		}

		return null;
	}

	public function ldpa_student_child_records() {
		global $wpdb;

		$table   = $wpdb->prefix . 'ldap_child_parent';
		$results = $wpdb->get_results(
			"SELECT
			{$table}.id,
			{$table}.parent_id,
			{$table}.child_id,
			{$table}.is_child_confirmed,
			parent.display_name parent_display_name,
			parent.user_nicename parent_nicename,
			child.display_name child_display_name,
			child.user_nicename child_nicename
			FROM {$table}
			LEFT JOIN {$wpdb->users} as parent
			ON {$table}.parent_id = parent.id
			LEFT JOIN {$wpdb->users} as child
			ON {$table}.child_id = child.id
		"
		);

		return $results;
	}

	public function ldpa_get_current_user_children( $userId ) {
		global $wpdb;

		$table   = $wpdb->prefix . 'ldap_child_parent';
		$results = $wpdb->get_results(
			"SELECT
			{$table}.id,
			{$table}.parent_id,
			{$table}.child_id,
			{$table}.is_child_confirmed,
			parent.display_name parent_display_name,
			parent.user_nicename parent_nicename,
			child.display_name child_display_name,
			child.user_nicename child_nicename
			FROM {$table}
			LEFT JOIN {$wpdb->users} as parent
			ON {$table}.parent_id = parent.id
			LEFT JOIN {$wpdb->users} as child
			ON {$table}.child_id = child.id
			WHERE {$table}.parent_id = ${userId}
		"
		);

		return $results;
	}

	public function ldpa_get_user_quiz_activities( $userId, $courseId ) {
		global $wpdb;

		$sql_str = 'SELECT * FROM ' . LDLMS_DB::get_table_name( 'user_activity' ) . ' WHERE user_id = ' . absint( $userId ) . ' AND course_id = ' . absint( $courseId ) . " AND activity_type = 'quiz' ORDER BY activity_completed DESC";

		return $wpdb->get_results( $sql_str, ARRAY_A );

	}

	public function ldpa_get_user_quiz_certificate_status( $quizId, $userId ) {
		// check kung merong naka assign na certificate sa quizId na un
		// pag wala return no cert pag meron check kung hindi empty to: learndash_get_certificate_link
		$meta = get_post_meta( $quizId, '_sfwd-quiz', true );
		if ( is_array( $meta ) && ! empty( $meta ) ) {
			if ( ( ! isset( $meta['sfwd-quiz_certificate'] ) ) || ( empty( $meta['sfwd-quiz_certificate'] ) ) ) {
				return __( 'No Certificate Assigned', 'learndash-access-for-parents' );
			}
			$result = learndash_get_certificate_link( $quizId, $userId );
			if ( ! empty( $result ) ) {
				return __( 'Awarded', 'learndash-access-for-parents' );
			}

			return __( 'Not Awarded', 'learndash-access-for-parents' );
		}
		return __( 'No Certificate Assigned', 'learndash-access-for-parents' );
	}

	public function ldpa_get_lessons_for_course( $course_id = 0 ) {

		$opt = [
			'post_type'      => 'sfwd-lessons',
			'posts_per_page' => - 1,
			'meta_query'     => [
				[
					'key'     => 'course_id',
					'value'   => $course_id,
					'compare' => '=',
				],
			],
		];

		$posts = get_posts( $opt );

		return $posts;
	}

}
